EasyDevAppBarThemeData class

Constructors

EasyDevAppBarThemeData({Color? backgroundColor, double? actionIconSize, Color? actionIconColor, Color? titleColor, Alignment? titleAlignment, Color? leadingIconColor, double? leadingIconSize})
const

Properties

actionIconColor → Color?
final
actionIconSize → double?
final
backgroundColor → Color?
final
hashCode → int
The hash code for this object.
no setteroverride
leadingIconColor → Color?
final
leadingIconSize → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleAlignment → Alignment?
final
titleColor → Color?
final

Methods

copyWith({Color? backgroundColor, double? actionIconSize, Color? actionIconColor, Color? titleColor, Alignment? titleAlignment, Color? leadingIconColor, double? leadingIconSize}) → EasyDevAppBarThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override